# Get started

<img style="color: gray; float: left; width: 5em; margin-left: 2em; margin-right: 2em;" src="assets/logo.svg#only-light"></img>
<img style="color: gray; float: left; width: 5em; margin-left: 2em; margin-right: 2em;" src="assets/logo_dark.svg#only-dark"></img>


`ginseng` is a python package for accurate, and somewhat efficient, cell type annotation using [`jax`](https://github.com/jax-ml/jax) and [`zarr`](https://zarr.dev/). It provides a variety of classes and functions in a simple-to-use interface for on-disk dataset creation, iterators for model training or data processing, and a lightweight neural attention model for cell type annotation.

## Installation

`ginseng` can be installed using `pip`

```bash
pip install ginseng
```

Or, added to your project using `uv`

```bash
uv add ginseng
```

## License

`ginseng` is licensed under the MIT License (see <a href="https://github.com/tomouellette/ginseng/blob/main/LICENSE">LICENSE</a>).
